@@ -14,5 +14,5 @@ test -n "$SSH_ASKPASS" || {
 		;;
 	esac
 }
-export PATH=$(cygpath -a C:/bld/git_1566748280906/_h_env)/Library/bin:$PATH 
+export PATH=$(cygpath -a D:/bld/git_1568031419256/_h_env)/Library/bin:$PATH 
  
